==> opennebula-7.0.1-1-amd64.tar.gz: opennebula-7.0.1/src/fireedge/src/modules/components/Tabs/index.js <==
/* ------------------------------------------------------------------------- *
 * Copyright 2002-2025, OpenNebula Project, OpenNebula Systems               *
 *                                                                           *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may   *
 * not use this file except in compliance with the License. You may obtain   *
 * a copy of the License at                                                  *
 *                                                                           *
 * http://www.apache.org/licenses/LICENSE-2.0                                *
 *                                                                           *
 * Unless required by applicable law or agreed to in writing, software       *
 * distributed under the License is distributed on an "AS IS" BASIS,         *
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  *
 * See the License for the specific language governing permissions and       *
 * limitations under the License.                                            *
 * ------------------------------------------------------------------------- */

export * from '@modules/components/Tabs/Common'
export { default as AccountingTabs } from '@modules/components/Tabs/Accounting'
export { default as DatastoreTabs } from '@modules/components/Tabs/Datastore'
export { default as EmptyTabs } from '@modules/components/Tabs/EmptyTab'
export { default as FileTabs } from '@modules/components/Tabs/File'
export { default as ImageTabs } from '@modules/components/Tabs/Image'
export { default as MarketplaceAppsTabs } from '@modules/components/Tabs/MarketplaceApp'
export { default as MarketplaceTabs } from '@modules/components/Tabs/Marketplace'
export { default as QuotaTabs } from '@modules/components/Tabs/Quota'
export { default as SecurityGroupTabs } from '@modules/components/Tabs/SecurityGroup'
export { default as ServiceTabs } from '@modules/components/Tabs/Service'
export { default as ServiceTemplateTabs } from '@modules/components/Tabs/ServiceTemplate'
export { default as ShowbackTabs } from '@modules/components/Tabs/Showback'
export { default as SupportTabs } from '@modules/components/Tabs/Support'
export { default as VnTabs } from '@modules/components/Tabs/Vn'
export { default as VnTemplateTabs } from '@modules/components/Tabs/VnTemplate'
export { default as VrTabs } from '@modules/components/Tabs/VirtualRouter'
export { default as VmGroupTabs } from '@modules/components/Tabs/VmGroup'
export { default as VmTabs } from '@modules/components/Tabs/Vm'
export { default as VmTemplateTabs } from '@modules/components/Tabs/VmTemplate'
export { default as BackupJobsTabs } from '@modules/components/Tabs/BackupJobs'
export { default as BackupTabs } from '@modules/components/Tabs/Backup'
export { default as BaseTab } from '@modules/components/Tabs/Tab'
export { default as ClusterTabs } from '@modules/components/Tabs/Cluster'
export { default as GroupTabs } from '@modules/components/Tabs/Group'
export { default as HostTabs } from '@modules/components/Tabs/Host'
export { default as UserTabs } from '@modules/components/Tabs/User'
export { default as VDCTabs } from '@modules/components/Tabs/Vdc'
export { default as ZoneTabs } from '@modules/components/Tabs/Zone'

==> opennebula-7.1.80-1-amd64.tar.gz: opennebula-7.1.80/src/fireedge/src/modules/components/Tabs/index.js <==
/* ------------------------------------------------------------------------- *
 * Copyright 2002-2025, OpenNebula Project, OpenNebula Systems               *
 *                                                                           *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may   *
 * not use this file except in compliance with the License. You may obtain   *
 * a copy of the License at                                                  *
 *                                                                           *
 * http://www.apache.org/licenses/LICENSE-2.0                                *
 *                                                                           *
 * Unless required by applicable law or agreed to in writing, software       *
 * distributed under the License is distributed on an "AS IS" BASIS,         *
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  *
 * See the License for the specific language governing permissions and       *
 * limitations under the License.                                            *
 * ------------------------------------------------------------------------- */

export * from '@modules/components/Tabs/Common'
export { default as AccountingTabs } from '@modules/components/Tabs/Accounting'
export { default as DatastoreTabs } from '@modules/components/Tabs/Datastore'
export { default as DriverTabs } from '@modules/components/Tabs/Driver'
export { default as EmptyTabs } from '@modules/components/Tabs/EmptyTab'
export { default as FileTabs } from '@modules/components/Tabs/File'
export { default as ImageTabs } from '@modules/components/Tabs/Image'
export { default as MarketplaceAppsTabs } from '@modules/components/Tabs/MarketplaceApp'
export { default as MarketplaceTabs } from '@modules/components/Tabs/Marketplace'
export { default as QuotaTabs } from '@modules/components/Tabs/Quota'
export { default as ProviderTabs } from '@modules/components/Tabs/Provider'
export { default as SecurityGroupTabs } from '@modules/components/Tabs/SecurityGroup'
export { default as ServiceTabs } from '@modules/components/Tabs/Service'
export { default as ServiceTemplateTabs } from '@modules/components/Tabs/ServiceTemplate'
export { default as ShowbackTabs } from '@modules/components/Tabs/Showback'
export { default as SupportTabs } from '@modules/components/Tabs/Support'
export { default as VnTabs } from '@modules/components/Tabs/Vn'
export { default as VnTemplateTabs } from '@modules/components/Tabs/VnTemplate'
export { default as VrTabs } from '@modules/components/Tabs/VirtualRouter'
export { default as VmGroupTabs } from '@modules/components/Tabs/VmGroup'
export { default as VmTabs } from '@modules/components/Tabs/Vm'
export { default as VmTemplateTabs } from '@modules/components/Tabs/VmTemplate'
export { default as BackupJobsTabs } from '@modules/components/Tabs/BackupJobs'
export { default as BackupTabs } from '@modules/components/Tabs/Backup'
export { default as BaseTab } from '@modules/components/Tabs/Tab'
export { default as ClusterTabs } from '@modules/components/Tabs/Cluster'
export { default as GroupTabs } from '@modules/components/Tabs/Group'
export { default as HostTabs } from '@modules/components/Tabs/Host'
export { default as UserTabs } from '@modules/components/Tabs/User'
export { default as VDCTabs } from '@modules/components/Tabs/Vdc'
export { default as ZoneTabs } from '@modules/components/Tabs/Zone'
